@@ -2,11 +2,11 @@
 #######################################################################
 """Product class for the Zope 3 based product package
 
-$Id: exchangeannotationableadapter.py 51883 2008-10-20 19:14:59Z cray $
+$Id: exchangeannotationableadapter.py 52426 2009-01-31 16:37:31Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51883 $"
+__version__ = "$Revision: 52426 $"
 
 from mailbox import Mailbox
 from zope.annotation.interfaces import IAnnotations 
@@ -26,7 +26,6 @@ def IExchangeAnnotationAbleAdapter(context) :
              context,
              "++annotations++" + exchangeannotationkey
 		)
-        print "Activate Mailbox",an
     except KeyError :
     	IAnnotations(context)[exchangeannotationkey] = Mailbox()
     	dsa = IAnnotations(context)[exchangeannotationkey]
@@ -35,6 +34,5 @@ def IExchangeAnnotationAbleAdapter(context) :
         get().commit()
         #notify(ObjectAddedEvent(an,context,"++annotations++" + exchangeannotationkey))
         notify(ObjectAddedEvent(dsa,context,"++annotations++" + exchangeannotationkey))
-        print "Create Mailbox",an
 
     return an
